summaryrefslogtreecommitdiffstats
path: root/kpilot/kpilot/todoWidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpilot/kpilot/todoWidget.h')
-rw-r--r--kpilot/kpilot/todoWidget.h32
1 files changed, 16 insertions, 16 deletions
diff --git a/kpilot/kpilot/todoWidget.h b/kpilot/kpilot/todoWidget.h
index 14a139e51..18ea1f6d2 100644
--- a/kpilot/kpilot/todoWidget.h
+++ b/kpilot/kpilot/todoWidget.h
@@ -42,14 +42,14 @@ class TodoListView : public KListView
{
Q_OBJECT
public:
- TodoListView(QWidget * parent = 0, const char * name = 0 ):KListView(parent, name){};
+ TodoListView(TQWidget * parent = 0, const char * name = 0 ):KListView(parent, name){};
~TodoListView() {};
signals:
- void itemChecked(QCheckListItem*item);
- void itemChecked(QCheckListItem*item, bool on);
+ void itemChecked(TQCheckListItem*item);
+ void itemChecked(TQCheckListItem*item, bool on);
//protected:
public:
- void itemWasChecked(QCheckListItem*item, bool on) {
+ void itemWasChecked(TQCheckListItem*item, bool on) {
emit itemChecked(item);
emit itemChecked(item, on);
}
@@ -58,7 +58,7 @@ public:
class TodoCheckListItem : public PilotCheckListItem
{
public:
- TodoCheckListItem(QListView*parent, const QString&text, recordid_t pilotid, void*r);
+ TodoCheckListItem(TQListView*parent, const TQString&text, recordid_t pilotid, void*r);
~TodoCheckListItem() {};
virtual void stateChange(bool state);
};
@@ -68,11 +68,11 @@ class TodoWidget : public PilotComponent
Q_OBJECT
public:
- TodoWidget(QWidget* parent,const QString& dbpath);
+ TodoWidget(TQWidget* parent,const TQString& dbpath);
~TodoWidget();
// Pilot Component Methods:
- virtual bool preHotSync(QString &);
+ virtual bool preHotSync(TQString &);
virtual void postHotSync();
virtual void showComponent();
virtual void hideComponent();
@@ -82,8 +82,8 @@ public slots:
* Called when a particular todo is selected. This slot displays
* it in the viewer widget.
*/
- void slotShowTodo(QListViewItem*);
- void slotEditRecord(QListViewItem*item);
+ void slotShowTodo(TQListViewItem*);
+ void slotEditRecord(TQListViewItem*item);
void slotEditRecord();
void slotCreateNewRecord();
void slotDeleteRecord();
@@ -113,8 +113,8 @@ protected slots:
void slotSetCategory(int);
- void slotItemChecked(QCheckListItem*item, bool on);
- void slotItemRenamed(QListViewItem*item, const QString &txt, int nr);
+ void slotItemChecked(TQCheckListItem*item, bool on);
+ void slotItemRenamed(TQListViewItem*item, const TQString &txt, int nr);
private:
void setupWidget();
void updateWidget(); // Called with the lists have changed..
@@ -132,13 +132,13 @@ private:
* Create a sensible "title" for an todo, composed
* of first + last name if possible.
*/
- QString createTitle(PilotTodoEntry *,int displayMode);
+ TQString createTitle(PilotTodoEntry *,int displayMode);
/**
- * We use a QComboBox fCatList to hold the user-visible names
- * of all the categories. The QTextView fTodoInfo is for
+ * We use a TQComboBox fCatList to hold the user-visible names
+ * of all the categories. The TQTextView fTodoInfo is for
* displaying the currently selected todo, if any.
* The QListView fListBox lists all the todoes in the
* currently selected category.
*
* The entire todo database is read into memory in the
@@ -151,7 +151,7 @@ private:
QComboBox *fCatList;
QTextView *fTodoInfo;
PilotToDoInfo *fTodoAppInfo;
- QPtrList<PilotTodoEntry> fTodoList;
+ TQPtrList<PilotTodoEntry> fTodoList;
TodoListView *fListBox;
QPushButton *fEditButton,*fDeleteButton;
PilotDatabase *fTodoDB;
@@ -132,13 +132,13 @@ private:
* displaying the currently selected todo, if any.
- * The QListView fListBox lists all the todoes in the
+ * The TQListView fListBox lists all the todoes in the
* currently selected category.
*